Package: BASS
Version: 1.3.1
Date: 2023-7-1
Title: Bayesian Adaptive Spline Surfaces
Description: Bayesian fitting and sensitivity analysis methods for adaptive
    spline surfaces described in <doi:10.18637/jss.v094.i08>. Built to handle continuous and categorical inputs as well as
    functional or scalar output. An extension of the methodology in Denison, Mallick
    and Smith (1998) <doi:10.1023/A:1008824606259>.
Authors@R: c(person("Devin", "Francom", role = c("aut", "cre"), email = "devinfrancom@gmail.com"),
              person("Bruno", "Sanso", role = "ths"), person("Kellin", "Rumsey", role = "aut"))
License: GPL-3
Suggests: R.rsp, testthat (>= 2.1.0), parallel
VignetteBuilder: R.rsp
Imports: truncdist, hypergeo
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2023-07-01 17:36:04 UTC; dfrancom
Author: Devin Francom [aut, cre],
  Bruno Sanso [ths],
  Kellin Rumsey [aut]
Maintainer: Devin Francom <devinfrancom@gmail.com>
Repository: CRAN
Date/Publication: 2023-07-04 13:13:07 UTC
Built: R 4.6.0; ; 2026-04-26 02:47:06 UTC; unix
