# Generated by roxygen2: do not edit by hand

S3method(plot,bass)
S3method(plot,bassBasis)
S3method(plot,bassSob)
S3method(predict,bass)
S3method(predict,bassBasis)
S3method(print,bass)
S3method(print,bassBasis)
S3method(summary,bass)
S3method(summary,bassBasis)
export(bass)
export(bassBasis)
export(bassPCA)
export(calibrate.bassBasis)
export(sobol)
export(sobolBasis)
import(graphics)
import(hypergeo)
import(stats)
import(utils)
