Beneath a Steel Sky, CD Talkie                (C) Revolution Software Ltd 1993-
------------------------------                ---------------------------------
                                                             
August 1st 2003
***************
(License and legal stuff at the end of this file. Read it or we will send Joey
after you)

Some time ago, we (ScummVM) had the good fortune to come in contact with Tony
Warriner at Revolution Software Ltd. With their blessing and support, we then
obtained the original source code for Beneath a Steel Sky and added support for
it to our adventure game interpreter, ScummVM. And now, on the eve of ScummVM
0.5.0 (the first release featuring B.A.S.S support), Revolution Software Ltd.
has decided to release Sky to the public as freeware! 

"Beneath a Steel Sky is a 2D point-and-click science fiction thriller set in a
bleak vision of the future, originally published for DOS and the Amiga. You are
Robert Foster, an innocent outsider stranded in a vast city where oppressed
civilians live and work in soaring tower blocks... whilst the corrupt, covetous
and rich live underground, safe from all pollution. Alone, save for a robot
circuit board, Foster must fight for survival - and discover the sinister truth
behind both his own past and the city he has found himself trapped in."

Game Quickstart
***************
You need ScummVM version 0.5.0 or newer to play this game, which can be
downloaded at http://www.scummvm.org/.

ScummVM runs on many platforms, including Linux, Windows, Mac OS X, Windows CE
and others. However note that some platforms may not (yet) be capable of playing
all games. As of 0.5.0, BASS cannot be played on PalmOS and DreamCast.
Please see the ScummVM Compatibility List for information on newer versions.

You should always read the instructions included with the latest version of
ScummVM, but for here is a quick three-step guide for the impatient:

 1) Unzip the game to a directory and install ScummVM
 2) After running ScummVM, click the 'Add Game' button and browse to the 
    directory you just created.
 3) After adding the game to the list, on future plays simply select it
    from the 'Game List' and click 'Start'!

You can access the in-game save/load and options menu with the 'Options' key,
usually F5 on most platforms. As a final caveat, several lines of dialog in
the game are missing voices. This was present in the original, and is a bug.
This is the larger 'CD talkie' version, with speech. The smaller floppy
version can be downloaded from our homepage.

Be vigilant,
            James 'Ender' Brown,
            Project Leader,
            ScummVM (http://www.scummvm.org/)

P.S: If you like this, you should probably go buy Broken Sword III (Rev's latest
game) once it is released :)

P.P.S: Neither Revolution Software Ltd. nor ScummVM provide support for this
game. Walkthroughs and hints can easily be found online, but in case of
technical problems, feel free to ask for help on the ScummVM forums.

********************************************************************************
Special Thanks:
          A full list of credits for ScummVM can be found in its README file,
however the following people deserve special credit... and naturally the first
thanks should go to the creators of this game!

Tony Warriner, David Sykes, Dave Cummins, Dave Gibbons, etc: Thanks for making
a great game! And thanks to Tony and Revolution in general, for helping us let
everyone experience it on modern systems. We hope more will follow in your
footsteps, and good luck with Broken Sword III, and the future.

We would also like to thank our host, SourceForge.net (and its associated 
mirrors), for allowing us to host this file.

Next, Robert Goeffringmann, Oliver Kiehl and Joost Peters, who together 
(re)wrote the majority of the interpretation code for Beneath a Steel Sky,
based on the original assembly language sources provided by Revolution.

And last but not least, Ludvig Strigeus (for starting ScummVM), Max Horn (my
co-lead developer), and of course every other ScummVM porter, developer and
contributer - without whom none of this would have been possible.

********************************************************************************
The Legal Stuff:

Preamble:
  Basically, give this game away, share it with your friends. Don't remove this
Readme, or pretend you wrote it. You can include it in a software collection,
like a linux distribution or coverdisk (which may be sold), but using it in
things like commercial adventure game collections without asking is just playing
dirty. This preamble is not legally binding, but is to clarify the intent of the
following license.

License:
 1) You may distribute this game for free on any medium, provided this readme
and all associated copyright notices and disclaimers are left intact.

 2) You may charge a reasonable copying fee for this archive, and may distribute
it in aggregate as part of a larger & possibly commercial software distribution
(such as a Linux distribution or magazine coverdisk). You must provide proper
attribution and ensure this readme and all associated copyright notices, and
disclaimers are left intact.

 3) You may not charge a fee for the game itself. This includes reselling the
game as an individual item.

 4) You may modify the game as you wish.  You may also distribute modified
versions under the terms set forth in this license, but with the additional
requirement that the work is marked with a prominent notice which states that
it is a modified version.

 5) All game content is (C) Revolution Software Ltd. The ScummVM engine is (C)
The ScummVM Team (www.scummvm.org)

 6) THE GAMEDATA IN THIS ARCHIVE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING AND NOT LIMITED TO ANY IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
